@@ -1495,6 +1495,22 @@ def install(tool, check, all, yes, use_latest, debug):
                         failed += 1
                         failed_details.append((tool_name, ecosystem_name))
                 else:
+                    # On Windows, try custom .bat installers as final fallback
+                    if platform_info.os_type.value == 'windows':
+                        from medusa.platform.installers import WindowsCustomInstaller
+                        if WindowsCustomInstaller.can_install(tool_name):
+                            console.print(f"  → Using custom Windows installer...")
+                            if WindowsCustomInstaller.install(tool_name, debug=debug):
+                                console.print(f"  [green]✅ Installed successfully[/green]\n")
+                                installed += 1
+                                from medusa.platform.tool_cache import ToolCache
+                                cache = ToolCache()
+                                cache.mark_installed(tool_name)
+                                continue  # Skip to next tool
+                            else:
+                                console.print(f"  [red]❌ Custom installer failed[/red]")
+                                # Fall through to ecosystem check
+
                     # Check if ecosystem exists but not found
                     from medusa.platform.installers.base import EcosystemDetector
                     if tool_name in EcosystemDetector.ECOSYSTEM_MAP:
